@@ -16,6 +16,7 @@
 #    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 """A Git repository"""
 
+import six
 import subprocess
 import os.path
 import re
@@ -39,7 +40,7 @@ class GitRemote(object):
     def __init__(self, name, fetch_url, push_urls):
         self._name = name
         self._fetch_url = fetch_url
-        if isinstance(push_urls, basestring):
+        if isinstance(push_urls, six.string_types):
             self._push_urls = [push_urls]
         else:
             self._push_urls = [url for url in push_urls]
@@ -281,7 +282,7 @@ class GitRepository(object):
 
     @property
     def head(self):
-        """return the SHA1 of the current HEAD"""
+        """SHA1 of the current HEAD"""
         return self.rev_parse('HEAD')
 
 #{ Branches and Merging
@@ -295,16 +296,18 @@ class GitRepository(object):
         args = GitArgs("-m", branch, newbranch)
         self._git_command("branch", args.args)
 
-    def create_branch(self, branch, rev=None):
+    def create_branch(self, branch, rev=None, force=False):
         """
         Create a new branch
 
         @param branch: the branch's name
         @param rev: where to start the branch from
+        @param force: reset branch HEAD to start point, if it already exists
 
         If rev is None the branch starts form the current HEAD.
         """
         args = GitArgs(branch)
+        args.add_true(force, '--force')
         args.add_true(rev, rev)
         self._git_command("branch", args.args)
 
@@ -710,6 +713,21 @@ class GitRepository(object):
         """
         return self.describe(commit, pattern, abbrev=0)
 
+    def find_branch_tag(self, commit, branch, pattern=None):
+        """
+        Find the closest tag on a certain branch to a given commit
+
+        @param commit: the commit to describe
+        @type commit: C{str}
+        @type branch: C{str}
+        @param pattern: only look for tags matching I{pattern}
+        @type pattern: C{str}
+        @return: the found tag
+        @rtype: C{str}
+        """
+        base_commit = self.get_merge_base(commit, branch)
+        return self.describe(base_commit, pattern, abbrev=0)
+
     def get_tags(self, pattern=None):
         """
         List tags
@@ -818,6 +836,39 @@ class GitRepository(object):
         if ret:
             raise GitRepositoryError("Can't execute repository clean: %s" % err)
 
+    def status(self, pathlist=None):
+        """
+        Check status of repository.
+
+        @param pathlist: List of paths to check status for
+        @type pathlist: C{list}
+        @return C{dict} of C{lists} of paths, where key is a git status flag.
+        @rtype C{dict}
+        """
+        options = GitArgs('--porcelain', '-z')
+        if pathlist:
+            for path in pathlist:
+                options.add(path)
+
+        out, err, ret = self._git_inout('status', options.args,
+                                        extra_env={'LC_ALL': 'C'})
+        if ret:
+            raise GitRepositoryError("Can't get repository status: %s" % err)
+
+        elements = out.split('\x00')
+        result = defaultdict(list)
+
+        while elements[0] != '':
+            element = elements.pop(0)
+            status = element[:2]
+            filepath = element[3:]
+            # Expect to have two filenames for renames and copies
+            if status[0] in ['R', 'C']:
+                filepath = elements.pop(0) + '\x00' + filepath
+            result[status].append(filepath)
+
+        return result
+
     def is_empty(self):
         """
         Is the repository empty?
@@ -1210,7 +1261,7 @@ class GitRepository(object):
         """
         extra_env = {}
 
-        if isinstance(paths, basestring):
+        if isinstance(paths, six.string_types):
             paths = [ paths ]
 
         args = [ '-f' ] if force else []
@@ -1232,7 +1283,7 @@ class GitRepository(object):
         @param verbose: be verbose
         @type verbose: C{bool}
         """
-        if isinstance(paths, basestring):
+        if isinstance(paths, six.string_types):
             paths = [ paths ]
 
         args =  [] if verbose else ['--quiet']
@@ -1333,7 +1384,7 @@ class GitRepository(object):
         @param author_info: authorship information
         @type author_info: L{GitModifier}
         """
-        if isinstance(files, basestring):
+        if isinstance(files, six.string_types):
             files = [ files ]
         self._commit(msg=msg, args=files, author_info=author_info)
 
@@ -1462,7 +1513,7 @@ class GitRepository(object):
             args.add(until)
         args.add_cond(options, options)
         args.add("--")
-        if isinstance(paths, basestring):
+        if isinstance(paths, six.string_types):
             paths = [ paths ]
         args.add_cond(paths, paths)
 
@@ -1639,6 +1690,33 @@ class GitRepository(object):
         if ret:
             raise GitRepositoryError("Git diff failed")
         return output
+
+    def diff_status(self, obj1, obj2):
+        """
+        Get file-status of two git repository objects
+
+        @param obj1: first object
+        @type obj1: C{str}
+        @param obj2: second object
+        @type obj2: C{str}
+        @return: name-status
+        @rtype: C{defaultdict} of C{str}
+        """
+        options = GitArgs('--name-status', '-z', obj1, obj2)
+        output, stderr, ret = self._git_inout('diff', options.args)
+
+        elements = output.split('\x00')
+        result = defaultdict(list)
+
+        while elements[0] != '':
+            status = elements.pop(0)[0]
+            filepath = elements.pop(0)
+            # Expect to have two filenames for renames and copies
+            if status in ['R', 'C']:
+                filepath = elements.pop(0) + '\x00' + filepath
+            result[status].append(filepath)
+
+        return result
 #}
 
     def archive(self, format, prefix, output, treeish, **kwargs):
@@ -1673,18 +1751,23 @@ class GitRepository(object):
 
 #{ Submodules
 
-    def has_submodules(self):
+    def has_submodules(self, treeish=None):
         """
         Does the repo have any submodules?
 
+        @param treeish: look into treeish
+        @type treeish: C{str}
         @return: C{True} if the repository has any submodules, C{False}
             otherwise
         @rtype: C{bool}
         """
-        if os.path.exists(os.path.join(self.path, '.gitmodules')):
+        if treeish:
+            try:
+                self.show('%s:.gitmodules' % treeish)
+            except GitRepositoryError:
+                return False
             return True
-        else:
-            return False
+        return os.path.exists(os.path.join(self.path, '.gitmodules'))
 
 
     def add_submodule(self, repo_path):
