@@ -1,6 +1,6 @@
 # vim: set fileencoding=utf-8 :
 #
-# (C) 2009,2010 Guido Guenther <agx@sigxcpu.org>
+# (C) 2009, 2010, 2015 Guido Guenther <agx@sigxcpu.org>
 #    This program is free software; you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
 #    the Free Software Foundation; either version 2 of the License, or
@@ -17,9 +17,9 @@
 #
 # inspired by dom-git-checkout
 #
-"""Clone a GIT repository and set it up for gbp"""
+"""Clone a Git repository and set it up for gbp"""
 
-import ConfigParser
+from six.moves import configparser
 import sys
 import os, os.path
 from gbp.config import (GbpOptionParser, GbpOptionGroup)
@@ -33,7 +33,7 @@ def build_parser(name):
     try:
         parser = GbpOptionParser(command=os.path.basename(name), prefix='',
                                  usage='%prog [options] repository - clone a remote repository')
-    except ConfigParser.ParsingError as err:
+    except configparser.ParsingError as err:
         gbp.log.err(err)
         return None
 
@@ -121,7 +121,7 @@ def main(argv):
         gbp.log.err("Git command failed: %s" % err)
         retval = 1
     except GbpError as err:
-        if len(err.__str__()):
+        if str(err):
             gbp.log.err(err)
         retval = 1
 
