@@ -14,7 +14,7 @@
 #    You should have received a copy of the GNU General Public License
 #    along with this program; if not, write to the Free Software
 #    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-"""Import multiple dsc files into GIT in one go"""
+"""Import multiple dsc files into Git in one go"""
 
 import glob
 import os
@@ -73,20 +73,19 @@ def set_gbp_conf_files():
     Filter out all gbp.conf files that are local to the git repository and set
     GBP_CONF_FILES accordingly so gbp import-dsc will only use these.
     """
-    files = GbpOptionParser.get_config_files()
-    global_config = [ f for f in files if f.startswith('/') ]
+    global_config = GbpOptionParser.get_config_files(no_local=True)
     gbp_conf_files = ':'.join(global_config)
     os.environ['GBP_CONF_FILES'] = gbp_conf_files
     gbp.log.debug("Setting GBP_CONF_FILES to '%s'" % gbp_conf_files)
 
 def print_help():
-    print """Usage: gbp import-dscs [options] [gbp-import-dsc options] /path/to/dsc1 [/path/to/dsc2] ...
+    print("""Usage: gbp import-dscs [options] [gbp-import-dsc options] /path/to/dsc1 [/path/to/dsc2] ...
        gbp import-dscs --debsnap [options] [gbp-import-dsc options] package
 
 Options:
 
     --ignore-repo-config: ignore gbp.conf in git repo
-"""
+""")
 
 
 def main(argv):
@@ -156,11 +155,11 @@ def main(argv):
                 raise GbpError("Failed to import '%s'" % dscs[0].dscfile)
 
     except (GbpError, gbpc.CommandExecFailed, GitRepositoryError) as err:
-        if len(err.__str__()):
+        if str(err):
             gbp.log.err(err)
         ret = 1
     finally:
-        if dirs.has_key('tmp'):
+        if 'tmp' in dirs:
             gbpc.RemoveTree(dirs['tmp'])()
         os.chdir(dirs['top'])
 
