@@ -1,6 +1,6 @@
 # vim: set fileencoding=utf-8 :
 #
-# (C) 2006, 2007, 2009, 2011 Guido Guenther <agx@sigxcpu.org>
+# (C) 2006, 2007, 2009, 2011, 2015 Guido Guenther <agx@sigxcpu.org>
 #    This program is free software; you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
 #    the Free Software Foundation; either version 2 of the License, or
@@ -15,9 +15,9 @@
 #    along with this program; if not, write to the Free Software
 #    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-"""Import a new upstream version into a GIT repository"""
+"""Import a new upstream version into a Git repository"""
 
-import ConfigParser
+from six.moves import configparser
 import os
 import sys
 import tempfile
@@ -29,11 +29,11 @@ from gbp.deb.changelog import ChangeLog, NoChangeLogError
 from gbp.deb.git import (GitRepositoryError, DebianGitRepository)
 from gbp.config import GbpOptionParserDebian, GbpOptionGroup, no_upstream_branch_msg
 from gbp.errors import GbpError
-from gbp.format import format_msg
+from gbp.format import format_str
 import gbp.log
 from gbp.scripts.common.import_orig import (orig_needs_repack, cleanup_tmp_tree,
                                             ask_package_name, ask_package_version,
-                                            repack_source, is_link_target)
+                                            repack_source, is_link_target, download_orig)
 
 
 def prepare_pristine_tar(archive, pkg, version):
@@ -187,7 +187,7 @@ def build_parser(name):
     try:
         parser = GbpOptionParserDebian(command=os.path.basename(name), prefix='',
                                        usage='%prog [options] /path/to/upstream-version.tar.gz | --uscan')
-    except ConfigParser.ParsingError as err:
+    except configparser.ParsingError as err:
         gbp.log.err(err)
         return None
 
@@ -208,7 +208,7 @@ def build_parser(name):
                       dest="debian_branch")
     branch_group.add_config_file_option(option_name="upstream-branch",
                       dest="upstream_branch")
-    branch_group.add_option("--upstream-vcs-tag", dest="vcs_tag",
+    branch_group.add_config_file_option(option_name="upstream-vcs-tag", dest="vcs_tag",
                             help="Upstream VCS tag add to the merge commit")
     branch_group.add_boolean_config_file_option(option_name="merge", dest="merge")
 
@@ -243,10 +243,25 @@ def build_parser(name):
                       default=False, help="deprecated - don't use.")
     parser.add_option("--uscan", dest='uscan', action="store_true",
                       default=False, help="use uscan(1) to download the new tarball.")
+    parser.add_option("--download", dest='download', action="store_true",
+                      default=False, help="Download from URL via http(s).")
     return parser
 
 
 def parse_args(argv):
+    """Parse the command line arguments
+    @return: options and arguments
+
+    # Silence error output
+    >>> _gbp_log_error_bak = gbp.log.error
+    >>> gbp.log.error = lambda x: None
+    >>> parse_args(['arg0', '--download', '--uscan'])
+    (None, None)
+    >>> parse_args(['arg0', '--download', 'first', 'second'])
+    (None, None)
+    >>> gbp.log.error = _gbp_log_error_bak
+    """
+
     parser = build_parser(argv[0])
     if not parser:
         return None, None
@@ -257,6 +272,14 @@ def parse_args(argv):
     if options.no_dch:
         gbp.log.warn("'--no-dch' passed. This is now the default, please remove this option.")
 
+    if options.uscan and options.download:
+        gbp.log.error("Either uscan or --download can be used, not both.")
+        return None, None
+
+    if options.download and len(args) != 1:
+        gbp.log.error("Need exactly one URL to download not %s" % args)
+        return None, None
+
     return options, args
 
 
@@ -271,7 +294,10 @@ def main(argv):
         return 1
 
     try:
-        source = find_source(options.uscan, args)
+        if options.download:
+            source = download_orig(args[0])
+        else:
+            source = find_source(options.uscan, args)
         if not source:
             return ret
 
@@ -331,7 +357,7 @@ def main(argv):
             msg = upstream_import_commit_msg(options, version)
 
             if options.vcs_tag:
-                parents = [repo.rev_parse("%s^{}" % options.vcs_tag)]
+                parents = [repo.rev_parse("%s^{}" % repo.version_to_tag(options.vcs_tag, version))]
             else:
                 parents = None
 
@@ -374,7 +400,7 @@ def main(argv):
                             epoch = '%s:' % cp.epoch
                     info = { 'version': "%s%s-1" % (epoch, version) }
                     env = { 'GBP_BRANCH': options.debian_branch }
-                    gbpc.Command(format_msg(options.postimport, info), extra_env=env, shell=True)()
+                    gbpc.Command(format_str(options.postimport, info), extra_env=env, shell=True)()
             # Update working copy and index if we've possibly updated the
             # checked out branch
             current_branch = repo.get_branch()
@@ -382,10 +408,10 @@ def main(argv):
                                    repo.pristine_tar_branch]:
                 repo.force_head(current_branch, hard=True)
         except (gbpc.CommandExecFailed, GitRepositoryError) as err:
-            msg = err.__str__() if len(err.__str__()) else ''
+            msg = str(err) or 'Unknown error, please report a bug'
             raise GbpError("Import of %s failed: %s" % (source.path, msg))
     except GbpError as err:
-        if len(err.__str__()):
+        if str(err):
             gbp.log.err(err)
         ret = 1
 
